**Example 1: 500G TSSD 额外购买300M性能**

500G TSSD 额外购买300M性能

Input: 

```
tccli cbs ModifyDiskExtraPerformance --cli-unfold-argument  \
    --ThroughputPerformance 300 \
    --DiskId disk-dritwhhm
```

Output: 
```
{
    "Response": {
        "RequestId": "d010c751-3edb-4388-878c-123fe111d1111owngrade400"
    }
}
```

